Crate swc_experimental_allocator

Crate swc_experimental_allocator 

Modules

atom
boxed
Based on bumpalo::boxed from the bumpalo crate, with some modifications to fit our use case:
hash_map
From https://github.com/oxc-project/oxc/blob/65f9233148aa8bb4ea433130c040675e14255c36/crates/oxc_allocator/src/hash_map.rs
hash_set
From https://github.com/oxc-project/oxc/blob/65f9233148aa8bb4ea433130c040675e14255c36/crates/oxc_allocator/src/hash_set.rs
raw_vec
vec
A contiguous growable array type with heap-allocated contents, written Vec<'bump, T>.
wtf8
Implementation of the WTF-8 encoding.

Macros

vec
Creates a Vec containing the arguments.

Structs

Allocator

Traits

CloneIn
FromIn
This trait works similarly to the standard library From trait.
IntoIn
This trait works similarly to the standard library Into trait.