Module raw_vec

Module raw_vec 

Structs

RawVec
A low-level utility for more ergonomically allocating, reallocating, and deallocating a buffer of memory on the heap without having to worry about all the corner cases involved. This type is excellent for building your own data structures like Vec and VecDeque. In particular:

Enums

CollectionAllocErr
Augments allocator errors with a capacity overflow variant.